@@ -46,7 +46,7 @@ class SignIn:
         raise web.SeeOther(
             indieauth.initiate_signin(
                 tx.origin,
-                "guests/authorize",
+                f"{tx.origin}/guests/authorize",
                 form.me,
                 ["profile", "email"],
                 tx.user.session,
